| Home | Libraries | People | FAQ | More

### remove_reference

    template <class T>
    struct remove_reference
    {
       typedef see-below type;
    };

type: The same type as `T`, but with any reference modifier removed.

C++ Standard Reference: 8.3.2.

Compiler Compatibility: If the compiler does not support partial specialization of class-templates then this template will compile, but the member `type` will always be the same as type `T` except where compiler workarounds have been applied.

Header: `#include <boost/type_traits/remove_reference.hpp>` or `#include <boost/type_traits.hpp>`

Table 1.30. Examples

Expression | Result Type
--- | ---
`remove_reference<int>::type` | `int`
`remove_reference<int const&>::type` | `int const`
`remove_reference<int&&>::type` | `int`
`remove_reference<int*>::type` | `int*`
`remove_reference<int*&>::type` | `int*`